summaryrefslogtreecommitdiff
path: root/extract-files.sh
diff options
context:
space:
mode:
Diffstat (limited to 'extract-files.sh')
-rwxr-xr-xextract-files.sh12
1 files changed, 9 insertions, 3 deletions
diff --git a/extract-files.sh b/extract-files.sh
index e4b602b..ba51122 100755
--- a/extract-files.sh
+++ b/extract-files.sh
@@ -17,7 +17,7 @@
set -e
-DEVICE=wayne
+DEVICE_COMMON=wayne-common
VENDOR=xiaomi
# Load extract_utils and do some sanity checks
@@ -55,9 +55,15 @@ if [ -z "$SRC" ]; then
SRC=adb
fi
-# Initialize the helper
-setup_vendor "$DEVICE" "$VENDOR" "$LINEAGE_ROOT" false $clean_vendor
+# Initialize the common helper
+setup_vendor "$DEVICE_COMMON" "$VENDOR" "$LINEAGE_ROOT" true $clean_vendor
extract "$MY_DIR"/proprietary-files.txt "$SRC" "$SECTION"
+if [ -s "$MY_DIR"/../$DEVICE/proprietary-files.txt ]; then
+ # Reinitialize the helper for device
+ setup_vendor "$DEVICE" "$VENDOR" "$LINEAGE_ROOT" false "$CLEAN_VENDOR"
+ extract "$MY_DIR"/../$DEVICE/proprietary-files.txt "$SRC" "$SECTION"
+fi
+
"$MY_DIR"/setup-makefiles.sh